@@ -144,13 +144,21 @@ def genPNLMap(lstpnl: list, funcGetXY) -> dict:
     arrx.sort()
     arry.sort()
 
+    first = True
+
     for y in arry:
         fv0['y'].append(y)
+        fv0['data'].append([])
 
         for x in arrx:
-            if arry.index(cr['y']) == 0:
+            if first:
                 fv0['x'].append(x)
 
-            fv0['data'].append(mapd[y][x])
+            if (y in mapd) and (x in mapd[y]):
+                fv0['data'][len(fv0['data']) - 1].append(mapd[y][x])
+            else:
+                fv0['data'][len(fv0['data']) - 1].append(0)
+        
+        first = False
 
     return fv0
\ No newline at end of file
